@@ -22,14 +22,10 @@ package com.verisign.epp.interfaces;
 // JUNIT Imports
 import java.util.Random;
 
-import junit.framework.Assert;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.log4j.Logger;
 
 import com.verisign.epp.codec.allocationtoken.EPPAllocationToken;
+import com.verisign.epp.codec.allocationtoken.EPPAllocationTokenInfo;
 import com.verisign.epp.codec.domain.EPPDomainCheckResp;
 import com.verisign.epp.codec.domain.EPPDomainCreateResp;
 import com.verisign.epp.codec.domain.EPPDomainInfoResp;
@@ -40,16 +36,21 @@ import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
- * Is a unit test of the <code>EPPAllocationToken</code> class. The unit test will
- * initialize a session with an EPP Server, will invoke <code>EPPDomain</code>
- * operations with the Allocation Token Extension, and will end a session with an EPP Server. 
- * The configuration file
- * used by the unit test defaults to epp.config, but can be changed by passing
- * the file path as the first command line argument. The unit test can be run in
- * multiple threads by setting the "threads" system property. For example, the
- * unit test can be run in 2 threads with the configuration file
- * ../../epp.config with the following command: <br>
+ * Is a unit test of the <code>EPPAllocationToken</code> class. The unit test
+ * will initialize a session with an EPP Server, will invoke
+ * <code>EPPDomain</code> operations with the Allocation Token Extension, and
+ * will end a session with an EPP Server. The configuration file used by the
+ * unit test defaults to epp.config, but can be changed by passing the file path
+ * as the first command line argument. The unit test can be run in multiple
+ * threads by setting the "threads" system property. For example, the unit test
+ * can be run in 2 threads with the configuration file ../../epp.config with the
+ * following command: <br>
  * <br>
  * java com.verisign.epp.interfaces.EPPAllocationTokenDomainTst -Dthreads=2
  * ../../epp.config <br>
@@ -68,16 +69,14 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	 * Handle to the Singleton EPP Application instance (
 	 * <code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app = EPPApplicationSingle
-			.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(
-			EPPAllocationTokenDomainTst.class.getName(), EPPCatFactory
-					.getInstance().getFactory());
+	private static final Logger cat = Logger.getLogger(EPPAllocationTokenDomainTst.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
@@ -92,18 +91,18 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	private int iteration = 0;
 
 	/**
-	 * Random instance for the generation of unique objects (hosts, IP
-	 * addresses, etc.).
+	 * Random instance for the generation of unique objects (hosts, IP addresses,
+	 * etc.).
 	 */
 	private Random rd = new Random(System.currentTimeMillis());
 
 	/**
-	 * Allocates an <code>EPPAllocationTokenDomainTst</code> with a logical
-	 * name. The constructor will initialize the base class
-	 * <code>TestCase</code> with the logical name.
+	 * Allocates an <code>EPPAllocationTokenDomainTst</code> with a logical name.
+	 * The constructor will initialize the base class <code>TestCase</code> with
+	 * the logical name.
 	 *
 	 * @param name
-	 *            Logical name of the test
+	 *           Logical name of the test
 	 */
 	public EPPAllocationTokenDomainTst(String name) {
 		super(name);
@@ -153,11 +152,9 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 
 		try {
 			// Check domain names example.tld and example2.tld
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 
-			System.out
-					.println("domainCheck: Check domain names example.tld and example2.tld with allocation token");
+			System.out.println("domainCheck: Check domain names example.tld and example2.tld with allocation token");
 
 			domain.setTransId("ABC-12345");
 
@@ -171,11 +168,9 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 
 			System.out.println("Response Type = " + response.getType());
 
-			System.out.println("Response.TransId.ServerTransId = "
-					+ response.getTransId().getServerTransId());
+			System.out.println("Response.TransId.ServerTransId = " + response.getTransId().getServerTransId());
 
-			System.out.println("Response.TransId.ServerTransId = "
-					+ response.getTransId().getClientTransId());
+			System.out.println("Response.TransId.ServerTransId = " + response.getTransId().getClientTransId());
 
 			// Output all of the response attributes
 			System.out.println("\ndomainCheck: Response = [" + response + "]");
@@ -196,15 +191,14 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 		EPPDomainInfoResp response;
 
 		try {
-			System.out
-					.println("\ndomainInfo: Domain info for example.tld with allocation token");
+			System.out.println("\ndomainInfo: Domain info for example.tld with allocation token");
 
 			domain.setTransId("ABC-12345");
 
 			domain.addDomainName("example.tld");
 
 			// Set empty allocation token extension
-			domain.addExtension(new EPPAllocationToken());
+			domain.addExtension(new EPPAllocationTokenInfo());
 
 			response = domain.sendInfo();
 
@@ -212,14 +206,11 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 			System.out.println("domainInfo: Response = [" + response + "]\n\n");
 
 			if (response.hasExtension(EPPAllocationToken.class)) {
-				EPPAllocationToken theExt = (EPPAllocationToken) response
-						.getExtension(EPPAllocationToken.class);
-				System.out.println("domain:info: Response allocation token = "
-						+ theExt.getToken());
+				EPPAllocationToken theExt = (EPPAllocationToken) response.getExtension(EPPAllocationToken.class);
+				System.out.println("domain:info: Response allocation token = " + theExt.getToken());
 			}
 			else {
-				System.out
-						.println("domainInfo: Response did not contain allocation token");
+				System.out.println("domainInfo: Response did not contain allocation token");
 			}
 		}
 		catch (EPPCommandException e) {
@@ -239,11 +230,9 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 		EPPDomainCreateResp response;
 
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 
-			System.out
-					.println("domainCreate: Create domain with allocation token");
+			System.out.println("domainCreate: Create domain with allocation token");
 
 			domain.setTransId("ABC-12345-XYZ");
 
@@ -257,14 +246,12 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 			response = domain.sendCreate();
 
 			// -- Output all of the response attributes
-			System.out.println("domainCreate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("domainCreate: Response = [" + response + "]\n\n");
 
 			// -- Output response attributes using accessors
 			System.out.println("domainCreate: name = " + response.getName());
 
-			System.out.println("domainCreate: expiration date = "
-					+ response.getExpirationDate());
+			System.out.println("domainCreate: expiration date = " + response.getExpirationDate());
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -283,8 +270,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 		EPPDomainTransferResp response;
 
 		try {
-			System.out
-					.println("\ndomainTransfer: Domain transfer request of example1.tld with allocation token");
+			System.out.println("\ndomainTransfer: Domain transfer request of example1.tld with allocation token");
 
 			domain.setTransferOpCode(EPPDomain.TRANSFER_REQUEST);
 
@@ -304,8 +290,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 			response = domain.sendTransfer();
 
 			// -- Output all of the response attributes
-			System.out.println("domainTransfer: Response = [" + response
-					+ "]\n\n");
+			System.out.println("domainTransfer: Response = [" + response + "]\n\n");
 		}
 
 		catch (EPPCommandException e) {
@@ -325,8 +310,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 		EPPResponse response;
 
 		try {
-			System.out
-					.println("\ndomainUpdate: Domain update of example1.tld with allocation token");
+			System.out.println("\ndomainUpdate: Domain update of example1.tld with allocation token");
 
 			domain.setTransId("ABC-12345-XYZ");
 
@@ -341,8 +325,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 			response = domain.sendUpdate();
 
 			// -- Output all of the response attributes
-			System.out.println("domainUpdate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("domainUpdate: Response = [" + response + "]\n\n");
 
 		}
 		catch (EPPCommandException e) {
@@ -353,17 +336,15 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute
-	 * is initialized with the attributes defined in the EPP sample files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
 
 		// Set attributes for initSession
-		session.setClientID(Environment.getProperty("EPP.Test.clientId",
-				"ClientX"));
-		session.setPassword(Environment.getProperty("EPP.Test.password",
-				"foo-BAR2"));
+		session.setClientID(Environment.getProperty("EPP.Test.clientId", "ClientX"));
+		session.setPassword(Environment.getProperty("EPP.Test.password", "foo-BAR2"));
 		session.setTransId("ABC-12345-XYZ");
 		session.setVersion("1.0");
 		session.setLang("en");
@@ -436,15 +417,13 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-								+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.newInstance();
+					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
 				catch (Exception ex) {
-					Assert.fail("Exception instantiating EPP.SessionClass value "
-							+ theSessionClassName + ": " + ex);
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
@@ -473,8 +452,8 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	}
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPAllocationTokenDomainTst</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>EPPAllocationTokenDomainTst</code>.
 	 *
 	 * @return Test suite
 	 */
@@ -506,7 +485,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	 * :&lt;Exception Description&gt;" will be specified.
 	 *
 	 * @param aException
-	 *            Exception thrown during test
+	 *           Exception thrown during test
 	 */
 	public void handleException(Exception aException) {
 		EPPResponse response = session.getResponse();
@@ -527,17 +506,15 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	 * Unit test main, which accepts the following system property options: <br>
 	 * 
 	 * <ul>
-	 * <li>
-	 * iterations Number of unit test iterations to run</li>
-	 * <li>
-	 * validate Turn XML validation on (<code>true</code>) or off (
+	 * <li>iterations Number of unit test iterations to run</li>
+	 * <li>validate Turn XML validation on (<code>true</code>) or off (
 	 * <code>false</code>). If validate is not specified, validation will be
 	 * off.</li>
 	 * </ul>
 	 * 
 	 *
 	 * @param args
-	 *            Command line arguments
+	 *           Command line arguments
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -559,8 +536,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread = new TestThread("EPPSessionTst Thread " + i,
-						EPPAllocationTokenDomainTst.suite());
+				TestThread thread = new TestThread("EPPSessionTst Thread " + i, EPPAllocationTokenDomainTst.suite());
 
 				thread.start();
 			}
@@ -590,8 +566,7 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	public String makeDomainName() {
 		long tm = System.currentTimeMillis();
 
-		return new String(Thread.currentThread()
-				+ String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
+		return new String(Thread.currentThread() + String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
 	}
 
 	/**
@@ -602,25 +577,24 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	public String makeIP() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(50)).substring(10)
-				+ "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
-				+ String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
-				+ String.valueOf(tm + rd.nextInt(50)).substring(10));
+		return new String(
+		      String.valueOf(tm + rd.nextInt(50)).substring(10) + "." + String.valueOf(tm + rd.nextInt(50)).substring(10)
+		            + "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
+		            + String.valueOf(tm + rd.nextInt(50)).substring(10));
 	}
 
 	/**
 	 * Makes a unique host name for a domain using the current time.
 	 *
 	 * @param newDomainName
-	 *            DOCUMENT ME!
+	 *           DOCUMENT ME!
 	 *
 	 * @return Unique host name <code>String</code>
 	 */
 	public String makeHostName(String newDomainName) {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-				+ "." + newDomainName);
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + newDomainName);
 	}
 
 	/**
@@ -631,30 +605,26 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	public String makeContactName() {
 		long tm = System.currentTimeMillis();
 
-		return new String("Con"
-				+ String.valueOf(tm + rd.nextInt(5)).substring(7));
+		return new String("Con" + String.valueOf(tm + rd.nextInt(5)).substring(7));
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 *
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " Start");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
 
-		System.out
-				.println("****************************************************************\n");
+		System.out.println("****************************************************************\n");
 	}
 
 	/**
@@ -662,18 +632,15 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	 * thread is a <code>TestThread</code>.
 	 *
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printEnd(String aTest) {
-		System.out
-				.println("****************************************************************");
+		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " End");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " End");
 		}
 
 		System.out.println("End of " + aTest);
@@ -685,15 +652,13 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	 * Print message
 	 *
 	 * @param aMsg
-	 *            message to print
+	 *           message to print
 	 */
 	private void printMsg(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.println(Thread.currentThread().getName()
-					+ ", iteration " + iteration + ": " + aMsg);
+			System.out.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aMsg);
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 
 		else {
@@ -707,15 +672,13 @@ public class EPPAllocationTokenDomainTst extends TestCase {
 	 * Print error message
 	 *
 	 * @param aMsg
-	 *            errpr message to print
+	 *           errpr message to print
 	 */
 	private void printError(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.err.println(Thread.currentThread().getName()
-					+ ", iteration " + iteration + ": " + aMsg);
+			System.err.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 
-			cat.error(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aMsg);
+			cat.error(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 
 		else {
