@@ -309,11 +309,11 @@ public class EPPContactTst extends TestCase {
 	 * This test will be invoked by JUNIT, since it is prefixed with "test" and
 	 * is a public method.
 	 */
-	public void testContactUpate() {
+	public void testContactUpdate() {
 		EPPContactUpdateCmd theCommand = null;
 		EPPEncodeDecodeStats commandStats = null;
 
-		EPPCodecTst.printStart("testContactUpate");
+		EPPCodecTst.printStart("testContactUpdate");
 
 		// Streets
 		Vector streets = new Vector();
@@ -373,10 +373,9 @@ public class EPPContactTst extends TestCase {
 		EPPEncodeDecodeStats responseStats = EPPCodecTst.testEncodeDecode(theResponse);
 		System.out.println(responseStats);
 
-		EPPCodecTst.printEnd("testContactUpate");
+		EPPCodecTst.printEnd("testContactUpdate");
 	}
 
-	// End EPPContactTst.testContactUpate()
 
 	/**
 	 * Unit test of <code>EPPContactTransferCmd</code>. The response to
