@@ -698,4 +698,14 @@ public class EPPFeeObjectResult implements EPPCodecComponent {
 		return true;
 	}
 
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPFeeExtFactory.NS;
+	}
+
 }
