@@ -26,10 +26,14 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.StringReader;
 import java.util.Date;
+import java.util.List;
 import java.util.Properties;
+import java.util.Set;
 import java.util.Vector;
 
 import javax.xml.parsers.DocumentBuilder;
+import javax.xml.parsers.DocumentBuilderFactory;
+import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.OutputKeys;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerFactory;
@@ -41,7 +45,6 @@ import org.apache.log4j.FileAppender;
 import org.apache.log4j.Level;
 import org.apache.log4j.Logger;
 import org.apache.log4j.PatternLayout;
-import org.apache.xerces.dom.DocumentImpl;
 import org.w3c.dom.Document;
 import org.w3c.dom.DocumentFragment;
 import org.w3c.dom.Element;
@@ -105,7 +108,7 @@ public class EPPCodecTst extends TestCase {
 	 */
 	public EPPCodecTst(String aName) {
 		super(aName);
-	} // End EPPCodecTst(String)
+	}
 
 	/**
 	 * Unit test of <code>EPPGreeting</code>. There is no response associated
@@ -123,8 +126,7 @@ public class EPPCodecTst extends TestCase {
 		// Add services
 		EPPServiceMenu serviceMenu = theGreeting.getServiceMenu();
 		Vector services = new Vector();
-		EPPService service = new EPPService("domain", "urn:ietf:params:xml:ns:domain-1.0",
-		      "urn:iana:xml:ns:domain-1.0 domain-1.0.xsd");
+		EPPService service = new EPPService("domain", "urn:ietf:params:xml:ns:domain-1.0");
 		service.setServiceType(0);
 
 		services.addElement(service);
@@ -210,7 +212,7 @@ public class EPPCodecTst extends TestCase {
 		System.out.println(stats);
 
 		printEnd("testGreeting");
-	} // End EPPCodecTst.testGreeting()
+	}
 
 	/**
 	 * Unit test of <code>EPPLoginCmd</code>. The response to
@@ -224,16 +226,14 @@ public class EPPCodecTst extends TestCase {
 		Vector services = new Vector();
 
 		// Object services
-		EPPService service = new EPPService("domain", "urn:ietf:params:xml:ns:domain-1.0",
-		      "urn:iana:xml:ns:domain-1.0 domain-1.0.xsd");
+		EPPService service = new EPPService("domain", "urn:ietf:params:xml:ns:domain-1.0");
 		service.setServiceType(EPPService.OBJ_SERVICE);
 
 		services.addElement(service);
 
 		// Extension services
 		Vector extservices = new Vector();
-		EPPService extservice = new EPPService("domain-ext", "urn:ietf:params:xml:ns:domainext-1.0",
-		      "urn:iana:xml:ns:domainext-1.0 domainext-1.0.xsd");
+		EPPService extservice = new EPPService("domain-ext", "urn:ietf:params:xml:ns:domainext-1.0");
 		extservice.setServiceType(EPPService.EXT_SERVICE);
 		extservices.addElement(extservice);
 
@@ -260,7 +260,7 @@ public class EPPCodecTst extends TestCase {
 		System.out.println(responseStats);
 
 		printEnd("testLogin");
-	} // End EPPCodecTst.testLogin()
+	}
 
 	/**
 	 * Unit test of <code>EPPLogoutCmd</code>. The response to
@@ -286,7 +286,7 @@ public class EPPCodecTst extends TestCase {
 		System.out.println(responseStats);
 
 		printEnd("testLogout");
-	} // End EPPCodecTst.testLogout()
+	}
 
 	/**
 	 * Unit test of <code>EPPResponse</code>. This will test
@@ -297,16 +297,17 @@ public class EPPCodecTst extends TestCase {
 	public void testResponse() {
 		printStart("testResponse");
 
+		// Success
 		EPPResponse theResponse;
 		theResponse = new EPPResponse(new EPPTransId("ABC-12345", "54321-XYZ"));
 		theResponse.setResult(EPPResult.SUCCESS);
 
 		System.out.println("EPPResponse.toString = [" + theResponse + "]");
-		System.out.println("EPPTransId.toString = [" + theResponse.getTransId() + "]");
 
 		EPPEncodeDecodeStats responseStats = testEncodeDecode(theResponse);
 		System.out.println(responseStats);
 
+		// Success with extValue
 		theResponse = new EPPResponse(new EPPTransId("ABC-12345", "54321-XYZ"));
 
 		EPPResult theResult = new EPPResult(EPPResult.SUCCESS);
@@ -318,9 +319,22 @@ public class EPPCodecTst extends TestCase {
 
 		responseStats = testEncodeDecode(theResponse);
 		System.out.println(responseStats);
+		
+		// Error response
+		theResponse = new EPPResponse(new EPPTransId("ABC-12345", "54321-XYZ"));
+		
+		theResult = new EPPResult(EPPResult.PARAM_VALUE_POLICY_ERROR);
+		theResult.addExtValue(new EPPExtValue("error reason"));
+		theResponse.setResult(theResult);
+
+		System.out.println("EPPResponse.toString = [" + theResponse + "]");
+
+		responseStats = testEncodeDecode(theResponse);
+		System.out.println(responseStats);
+		
 
 		printEnd("testResponse");
-	} // End EPPCodecTst.testResponse()
+	}
 
 	/**
 	 * Test unhandled namespaces poll message, which is a poll message that
@@ -342,7 +356,8 @@ public class EPPCodecTst extends TestCase {
 		      "Message incomplete due to missing \"urn:ietf:params:xml:ns:changePoll-1.0\" extURI in login services",
 		      "<extURI>urn:ietf:params:xml:ns:changePoll-1.0</extURI>"));
 		theResponse.setResult(theResult);
-		theResponse.setMsgQueue(new EPPMsgQueue(Long.valueOf(1), "201", new Date(), "Registry initiated update of domain."));
+		theResponse
+		      .setMsgQueue(new EPPMsgQueue(Long.valueOf(1), "201", new Date(), "Registry initiated update of domain."));
 
 		System.out.println("EPPResponse.toString = [" + theResponse + "]");
 
@@ -381,10 +396,9 @@ public class EPPCodecTst extends TestCase {
 		 */
 		@Override
 		public String getNamespace() {
-			return EPPCodec.NS;
+			return "test1";
 		}
-
-	} // End class EPPCodecTst.Test1Extension
+	}
 
 	/**
 	 * A stubbed out test extension used for tests that simply add, remove, check
@@ -395,7 +409,7 @@ public class EPPCodecTst extends TestCase {
 	private static class Test2Extension implements EPPCodecComponent {
 
 		public Element encode(Document aDocument) throws EPPEncodeException {
-			Element root = aDocument.createElementNS(EPPCodec.NS, "test1");
+			Element root = aDocument.createElementNS(EPPCodec.NS, "test2");
 			return root;
 		}
 
@@ -415,10 +429,10 @@ public class EPPCodecTst extends TestCase {
 		 */
 		@Override
 		public String getNamespace() {
-			return EPPCodec.NS;
+			return "test2";
 		}
 
-	} // End class EPPCodecTst.Test2Extension
+	}
 
 	/**
 	 * Unit test for using {@link EPPCommand#getExtension(Class, boolean)}.
@@ -477,7 +491,83 @@ public class EPPCodecTst extends TestCase {
 		}
 
 		printEnd("testCommandGetExtensionFailOnDuplicate");
-	} // End EPPCodecTst.testCommandGetExtensionFailOnDuplicate()
+	}
+
+	/**
+	 * Unit test of using
+	 * {@link EPPUtil#findDuplicateExtNamespaces(List)} and
+	 * the corresponding {@link EPPCommand#findDuplicateExtNamespaces()} and
+	 * {@link EPPResponse#findDuplicateExtNamespaces()}. Test the following:<br>
+	 * <ol>
+	 * <li>Test that no duplicates are found
+	 * <li>Test that duplicates are found when there are a single set of
+	 * duplicates
+	 * <li>Test that multiple duplicate instances result in the same set of found
+	 * duplicates.
+	 * </ol>
+	 */
+	public void testFindDuplicateExtNamespaces() {
+		printStart("testFindDuplicateExtNamespaces");
+
+		EPPPollCmd theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		// First instances
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		Set<String> theDuplicateExtNamespaces = EPPUtil.findDuplicateExtNamespaces(theCommand.getExtensions());
+		Assert.assertNull(theDuplicateExtNamespaces);
+
+		theDuplicateExtNamespaces = theCommand.findDuplicateExtNamespaces();
+		Assert.assertNull(theDuplicateExtNamespaces);
+
+		// Second instances
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		theDuplicateExtNamespaces = EPPUtil.findDuplicateExtNamespaces(theCommand.getExtensions());
+		Assert.assertNotNull(theDuplicateExtNamespaces);
+		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+
+		theDuplicateExtNamespaces = theCommand.findDuplicateExtNamespaces();
+		Assert.assertNotNull(theDuplicateExtNamespaces);
+		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+
+		// Third instances
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		theDuplicateExtNamespaces = EPPUtil.findDuplicateExtNamespaces(theCommand.getExtensions());
+		Assert.assertNotNull(theDuplicateExtNamespaces);
+		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+
+		theDuplicateExtNamespaces = theCommand.findDuplicateExtNamespaces();
+		Assert.assertNotNull(theDuplicateExtNamespaces);
+		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+		
+		// Test EPPResponse
+		EPPResponse theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theDuplicateExtNamespaces = theResponse.findDuplicateExtNamespaces();
+		Assert.assertNotNull(theDuplicateExtNamespaces);
+		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+
+		printEnd("testFindDuplicateExtNamespaces");
+	}
 
 	/**
 	 * Unit test for using {@link EPPResponse#getExtension(Class, boolean)}.
@@ -537,7 +627,7 @@ public class EPPCodecTst extends TestCase {
 		}
 
 		printEnd("testResponseGetExtensionFailOnDuplicate");
-	} // End EPPCodecTst.testResponseGetExtensionFailOnDuplicate()
+	}
 
 	/**
 	 * JUNIT <code>setUp</code> method, which sets the default client Id to
@@ -545,13 +635,13 @@ public class EPPCodecTst extends TestCase {
 	 */
 	protected void setUp() {
 		// EPPTransId.setDefaultClientId("ClientX");
-	} // End EPPCodecTst.setUp();
+	}
 
 	/**
 	 * JUNIT <code>tearDown</code>, which currently does nothing.
 	 */
 	protected void tearDown() {
-	} // End EPPCodecTst.tearDown();
+	}
 
 	/**
 	 * Initialize the SDK environment based on the system properties:<br>
@@ -591,13 +681,13 @@ public class EPPCodecTst extends TestCase {
 
 			initialized = true;
 		}
-	} // End EPPCodecTst.initEnvironment()
+	}
 
 	/**
 	 * JUNIT <code>suite</code> static method, which returns the tests associated
 	 * with <code>EPPCodecTst</code>.
 	 *
-	 * @return DOCUMENT ME!
+	 * @return Test suite
 	 */
 	public static Test suite() {
 
@@ -613,7 +703,7 @@ public class EPPCodecTst extends TestCase {
 		}
 
 		return suite;
-	} // End EPPCodecTst.suite()
+	}
 
 	/**
 	 * Unit test main, which accepts the following system property options:<br>
@@ -649,7 +739,7 @@ public class EPPCodecTst extends TestCase {
 		else { // Single threaded mode.
 			junit.textui.TestRunner.run(EPPCodecTst.suite());
 		}
-	} // End EPPCodecTst.main(String [])
+	}
 
 	/**
 	 * Print the start of a test with the <code>Thread</code> name if the current
@@ -665,7 +755,7 @@ public class EPPCodecTst extends TestCase {
 
 		System.out.println("Start of " + aTest);
 		System.out.println("*************************************************************************************\n");
-	} // End EPPCodecTst.testStart(String)
+	}
 
 	/**
 	 * Print the end of a test with the <code>Thread</code> name if the current
@@ -683,7 +773,7 @@ public class EPPCodecTst extends TestCase {
 
 		System.out.println("End of " + aTest);
 		System.out.println("\n");
-	} // End EPPCodecTst.testEnd(String)
+	}
 
 	/**
 	 * Tests the encoding and decoding of an {@link EPPMessage}. If there is an
@@ -906,7 +996,7 @@ public class EPPCodecTst extends TestCase {
 	 */
 	public static void setNumIterations(long aNumIterations) {
 		numIterations = aNumIterations;
-	} // End EPPCodecTst.setNumIterations(long)
+	}
 
 	/**
 	 * Unit test of <code>EPPHello</code>. The response to <code>EPPHello</code>
@@ -923,15 +1013,16 @@ public class EPPCodecTst extends TestCase {
 		System.out.println(commandStats);
 
 		printEnd("testLogout");
-	} // End EPPCodecTst.testHello()
+	}
 
 	/**
 	 * Unit test of <code>EPPPollCmd</code>. The response to
 	 * <code>EPPPollCmd</code> is <code>EPPResponse</code>. <br>
 	 * This test will be invoked by JUNIT, since it is prefixed with "test" and
 	 * is a public method.
+	 * @throws ParserConfigurationException Error creating DOM document.
 	 */
-	public void testPoll() {
+	public void testPoll() throws ParserConfigurationException {
 		printStart("testPoll");
 
 		// Poll command
@@ -961,7 +1052,9 @@ public class EPPCodecTst extends TestCase {
 		// Create NodeList
 		Element theElm;
 		Text theText;
-		Document theDoc = new DocumentImpl();
+		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
+		DocumentBuilder builder = dbf.newDocumentBuilder();
+		Document theDoc = builder.newDocument();
 		DocumentFragment theFragment = theDoc.createDocumentFragment();
 
 		theElm = theDoc.createElement("code");
@@ -993,7 +1086,7 @@ public class EPPCodecTst extends TestCase {
 		System.out.println(responseStats);
 
 		printEnd("testPoll");
-	} // End EPPCodecTst.testPoll()
+	}
 
 	/**
 	 * Test the encoding and decoding of the <code>timeInstantFormat</code>
@@ -1023,4 +1116,4 @@ public class EPPCodecTst extends TestCase {
 		printEnd("testTimeInstantFormat");
 	}
 
-} 
+}
