@@ -419,7 +419,7 @@ public class EPPSessionTst extends TestCase {
 
 			if (theSessionClassName != null) {
 				try {
-					Class theSessionClass = Class.forName(theSessionClassName);
+					Class<?> theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
 						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
