@@ -813,4 +813,14 @@ public class EPPCourt implements EPPCodecComponent {
 		return EPPUtil.toString(this);
 	}
 
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPMark.NS;
+	}
+
 }
\ No newline at end of file
