@@ -755,4 +755,15 @@ public class EPPMarkContact implements EPPCodecComponent {
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
+	
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPMark.NS;
+	}
+	
 }
