@@ -49,27 +49,27 @@ import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
-
 /**
- * Is a unit test of the EPPSession class.  The unit test will initialize a
- * session with an EPP Server and end a session with an EPP Server.  The
+ * Is a unit test of the EPPSession class. The unit test will initialize a
+ * session with an EPP Server and end a session with an EPP Server. The
  * configuration file used by the unit test defaults to epp.config, but can be
- * changed by passing the file path as the first command line argument.  The
- * unit test can be run in multiple threads by setting     the "threads"
- * system property.  For example, the unit test can     be run in 2 threads
- * with the configuration file ../../epp.config with     the following command:<br>
+ * changed by passing the file path as the first command line argument. The unit
+ * test can be run in multiple threads by setting the "threads" system property.
+ * For example, the unit test can be run in 2 threads with the configuration
+ * file ../../epp.config with the following command:<br>
  * <br>
- * java com.verisign.epp.interfaces.EPPNamestoreExtHostTst -Dthreads=2 ../../epp.config <br>
+ * java com.verisign.epp.interfaces.EPPNamestoreExtHostTst -Dthreads=2
+ * ../../epp.config <br>
  * <br>
- * The unit test is dependent on the     use of <a
+ * The unit test is dependent on the use of <a
  * href=http://www.mcwestcorp.com/Junit.html>JUNIT 3.5</a><br>
  * <br>
- * The test <code>EPPResponse</code> is duplicated     for
- * <code>EPPMessage</code> that do not contain a specialized
- * <code>EPPResponse</code>     to provide an example of a full
- * <code>EPPMessage</code> transaction.  All of the com.verisign.epp.codec.gen
- * package <code>EPPMessage</code> classes are associated     with
- * <code>EPPResponse</code>.     <br><br>
+ * The test <code>EPPResponse</code> is duplicated for <code>EPPMessage</code>
+ * that do not contain a specialized <code>EPPResponse</code> to provide an
+ * example of a full <code>EPPMessage</code> transaction. All of the
+ * com.verisign.epp.codec.gen package <code>EPPMessage</code> classes are
+ * associated with <code>EPPResponse</code>. <br>
+ * <br>
  *
  * @author $Author: jim $
  * @version $Revision: 1.2 $
@@ -79,17 +79,14 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	 * Handle to the Singleton EPP Application instance
 	 * (<code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app =
-		EPPApplicationSingle.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat =
-		Logger.getLogger(
-						 EPPNamestoreExtHostTst.class.getName(),
-						 EPPCatFactory.getInstance().getFactory());
+	private static final Logger cat = Logger.getLogger(EPPNamestoreExtHostTst.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/** EPP Host associated with test */
 	private EPPHost host = null;
@@ -104,11 +101,12 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	private Random rd = new Random(System.currentTimeMillis());
 
 	/**
-	 * Allocates an <code>EPPNamestoreExtHostTst</code> with a logical name.  The
-	 * constructor will initialize the base class <code>TestCase</code> with
-	 * the logical name.
+	 * Allocates an <code>EPPNamestoreExtHostTst</code> with a logical name. The
+	 * constructor will initialize the base class <code>TestCase</code> with the
+	 * logical name.
 	 *
-	 * @param name Logical name of the test
+	 * @param name
+	 *           Logical name of the test
 	 */
 	public EPPNamestoreExtHostTst(String name) {
 		super(name);
@@ -117,22 +115,19 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	// End EPPNamestoreExtHostTst(String)
 
 	/**
-	 * JUNIT test method to implement the <code>EPPNamestoreExtHostTst TestCase</code>.
-	 * Each     sub-test will be invoked in order to satisfy testing the
-	 * EPPHost interface.
+	 * JUNIT test method to implement the
+	 * <code>EPPNamestoreExtHostTst TestCase</code>. Each sub-test will be
+	 * invoked in order to satisfy testing the EPPHost interface.
 	 */
 	public void testHost() {
-		int    numIterations = 1;
+		int numIterations = 1;
 		String iterationsStr = System.getProperty("iterations");
 
 		if (iterationsStr != null) {
 			numIterations = Integer.parseInt(iterationsStr);
 		}
 
-		for (
-			 iteration = 0;
-				 (numIterations == 0) || (iteration < numIterations);
-				 iteration++) {
+		for (iteration = 0; (numIterations == 0) || (iteration < numIterations); iteration++) {
 			printStart("Test Suite");
 
 			hostCheck();
@@ -166,13 +161,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			response = host.sendCheck();
 
 			// Output all of the response attributes
@@ -183,20 +178,17 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// For each result
 			for (int i = 0; i < response.getCheckResults().size(); i++) {
-				EPPHostCheckResult currResult =
-					(EPPHostCheckResult) response.getCheckResults().elementAt(i);
+				EPPHostCheckResult currResult = (EPPHostCheckResult) response.getCheckResults().elementAt(i);
 
 				if (currResult.isAvailable()) {
-					System.out.println("hostCheck: Host "
-									   + currResult.getName() + " is available");
+					System.out.println("hostCheck: Host " + currResult.getName() + " is available");
 				}
 				else {
-					System.out.println("hostCheck: Host "
-									   + currResult.getName() + " is unavailable");
+					System.out.println("hostCheck: Host " + currResult.getName() + " is unavailable");
 				}
 			}
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -215,7 +207,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			response = host.sendCheck();
 
 			// Output all of the response attributes
@@ -226,20 +218,17 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// For each result
 			for (int i = 0; i < response.getCheckResults().size(); i++) {
-				EPPHostCheckResult currResult =
-					(EPPHostCheckResult) response.getCheckResults().elementAt(i);
+				EPPHostCheckResult currResult = (EPPHostCheckResult) response.getCheckResults().elementAt(i);
 
 				if (currResult.isAvailable()) {
-					System.out.println("hostCheck: Host "
-									   + currResult.getName() + " is available");
+					System.out.println("hostCheck: Host " + currResult.getName() + " is available");
 				}
 				else {
-					System.out.println("hostCheck: Host "
-									   + currResult.getName() + " is unavailable");
+					System.out.println("hostCheck: Host " + currResult.getName() + " is unavailable");
 				}
 			}
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -266,28 +255,24 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			response = host.sendInfo();
 
-			//-- Output all of the response attributes
+			// -- Output all of the response attributes
 			System.out.println("hostInfo: Response = [" + response + "]\n\n");
 
-			//-- Output required response attributes using accessors
+			// -- Output required response attributes using accessors
 			System.out.println("hostInfo: name = " + response.getName());
-			System.out.println("hostInfo: client id = "
-							   + response.getClientId());
-			System.out.println("hostInfo: created by = "
-							   + response.getCreatedBy());
-			System.out.println("hostInfo: create date = "
-							   + response.getCreatedDate());
+			System.out.println("hostInfo: client id = " + response.getClientId());
+			System.out.println("hostInfo: created by = " + response.getCreatedBy());
+			System.out.println("hostInfo: create date = " + response.getCreatedDate());
 
-			//-- Output optional response attributes using accessors
+			// -- Output optional response attributes using accessors
 			// Addresses
 			if (response.getAddresses() != null) {
 				// For each Address
 				for (int i = 0; i < response.getAddresses().size(); i++) {
-					EPPHostAddress currAddress =
-						(EPPHostAddress) response.getAddresses().elementAt(i);
+					EPPHostAddress currAddress = (EPPHostAddress) response.getAddresses().elementAt(i);
 
 					System.out.print("hostInfo: address " + (i + 1));
 
@@ -308,17 +293,15 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Last Updated By
 			if (response.getLastUpdatedBy() != null) {
-				System.out.println("hostInfo: last updated by = "
-								   + response.getLastUpdatedBy());
+				System.out.println("hostInfo: last updated by = " + response.getLastUpdatedBy());
 			}
 
 			// Last Updated Date
 			if (response.getLastUpdatedDate() != null) {
-				System.out.println("hostInfo: last updated date = "
-								   + response.getLastUpdatedDate());
+				System.out.println("hostInfo: last updated date = " + response.getLastUpdatedDate());
 			}
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -346,13 +329,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			response = host.sendCreate();
 
-			//-- Output all of the response attributes
+			// -- Output all of the response attributes
 			System.out.println("hostCreate: Response = [" + response + "]\n\n");
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -370,13 +353,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			response = host.sendCreate();
 
-			//-- Output all of the response attributes
+			// -- Output all of the response attributes
 			System.out.println("hostCreate: Response = [" + response + "]\n\n");
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -400,13 +383,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			response = host.sendDelete();
 
-			//-- Output all of the response attributes
+			// -- Output all of the response attributes
 			System.out.println("hostDelete: Response = [" + response + "]\n\n");
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -434,23 +417,20 @@ public class EPPNamestoreExtHostTst extends TestCase {
 			// Remove attributes
 			host.removeIPV6Address("1080:0:0:0:8:800:200C:417A");
 
-			host.addStatus(
-						   EPPHost.STAT_OK, "Hello_World", EPPHost.DEFAULT_LANG);
+			host.addStatus(EPPHost.STAT_OK, "Hello_World", EPPHost.DEFAULT_LANG);
 
-			host.removeStatus(
-							  EPPHost.STAT_OK, "Hello World with spaces",
-							  EPPHost.DEFAULT_LANG);
+			host.removeStatus(EPPHost.STAT_OK, "Hello World with spaces", EPPHost.DEFAULT_LANG);
 
 			// Set destination registry
 			host.addExtension(new EPPNamestoreExtNamestoreExt("CC"));
-			
+
 			// Execute update
 			response = host.sendUpdate();
 
-			//-- Output all of the response attributes
+			// -- Output all of the response attributes
 			System.out.println("hostUpdate: Response = [" + response + "]\n\n");
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -460,8 +440,8 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	// End EPPNamestoreExtHostTst.hostUpdate()
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>.  The session attribute
-	 * is initialized with the attributes defined in the EPP sample files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
@@ -472,12 +452,12 @@ public class EPPNamestoreExtHostTst extends TestCase {
 		session.setTransId("ABC-12345-XYZ");
 		session.setVersion("1.0");
 		session.setLang("en");
-		
+
 		// Initialize the session
 		try {
 			session.initSession();
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			EPPResponse response = session.getResponse();
 
 			// Is a server specified error?
@@ -485,7 +465,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 				Assert.fail("Server Error : " + response);
 			}
 			else // Other error
-			 {
+			{
 				e.printStackTrace();
 				Assert.fail("initSession Error : " + e);
 			}
@@ -497,8 +477,8 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	// End EPPNamestoreExtHostTst.initSession()
 
 	/**
-	 * Unit test of <code>EPPSession.endSession</code>.  The session with the
-	 * EPP Server will be terminated.
+	 * Unit test of <code>EPPSession.endSession</code>. The session with the EPP
+	 * Server will be terminated.
 	 */
 	private void endSession() {
 		printStart("endSession");
@@ -509,7 +489,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 		try {
 			session.endSession();
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			EPPResponse response = session.getResponse();
 
 			// Is a server specified error?
@@ -517,7 +497,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 				Assert.fail("Server Error : " + response);
 			}
 			else // Other error
-			 {
+			{
 				e.printStackTrace();
 				Assert.fail("initSession Error : " + e);
 			}
@@ -541,15 +521,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-									+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.newInstance();
+					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
-				 catch (Exception ex) {
-					Assert.fail("Exception instantiating EPP.SessionClass value "
-								+ theSessionClassName + ": " + ex);
+				catch (Exception ex) {
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
@@ -557,7 +535,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 			}
 
 		}
-		 catch (Exception e) {
+		catch (Exception e) {
 			e.printStackTrace();
 			Assert.fail("Error initializing the session: " + e);
 		}
@@ -579,8 +557,8 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	// End EPPNamestoreExtHostTst.tearDown();
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPNamestoreExtHostTst</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>EPPNamestoreExtHostTst</code>.
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -588,13 +566,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 		TestSuite suite = new TestSuite(EPPNamestoreExtHostTst.class);
 
 		String theConfigFileName = System.getProperty("EPP.ConfigFile");
-		if (theConfigFileName != null) 
+		if (theConfigFileName != null)
 			configFileName = theConfigFileName;
-		
+
 		try {
 			app.initialize(configFileName);
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			e.printStackTrace();
 			Assert.fail("Error initializing the EPP Application: " + e);
 		}
@@ -606,13 +584,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 
 	/**
 	 * Handle an <code>EPPCommandException</code>, which can be either a server
-	 * generated error or a general exception.  If the exception     was
-	 * caused by a server error, "Server Error : &lt;Response XML&gt;" will be
-	 * specified.     If the exception was caused by a general     algorithm
-	 * error, "General Error : &lt;Exception Description&gt;" will     be
-	 * specified.
+	 * generated error or a general exception. If the exception was caused by a
+	 * server error, "Server Error : &lt;Response XML&gt;" will be specified. If
+	 * the exception was caused by a general algorithm error, "General Error :
+	 * &lt;Exception Description&gt;" will be specified.
 	 *
-	 * @param aException Exception thrown during test
+	 * @param aException
+	 *           Exception thrown during test
 	 */
 	public void handleException(EPPCommandException aException) {
 		EPPResponse response = session.getResponse();
@@ -622,7 +600,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 			Assert.fail("Server Error : " + response);
 		}
 		else // Other error
-		 {
+		{
 			aException.printStackTrace();
 			Assert.fail("General Error : " + aException);
 		}
@@ -634,18 +612,15 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	 * Unit test main, which accepts the following system property options:<br>
 	 * 
 	 * <ul>
-	 * <li>
-	 * iterations    Number of unit test iterations to run
-	 * </li>
-	 * <li>
-	 * validate    Turn XML validation on (<code>true</code>) or off
-	 * (<code>false</code>).     If validate is not specified, validation will
-	 * be off.
-	 * </li>
+	 * <li>iterations Number of unit test iterations to run</li>
+	 * <li>validate Turn XML validation on (<code>true</code>) or off
+	 * (<code>false</code>). If validate is not specified, validation will be
+	 * off.</li>
 	 * </ul>
 	 * 
 	 *
-	 * @param args DOCUMENT ME!
+	 * @param args
+	 *           DOCUMENT ME!
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -654,7 +629,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 		}
 
 		// Number of Threads
-		int    numThreads = 1;
+		int numThreads = 1;
 		String threadsStr = System.getProperty("threads");
 
 		if (threadsStr != null) {
@@ -665,10 +640,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread =
-					new TestThread(
-								   "EPPSessionTst Thread " + i,
-								   EPPNamestoreExtHostTst.suite());
+				TestThread thread = new TestThread("EPPSessionTst Thread " + i, EPPNamestoreExtHostTst.suite());
 				thread.start();
 			}
 		}
@@ -679,7 +651,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 		try {
 			app.endApplication();
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			e.printStackTrace();
 			Assert.fail("Error ending the EPP Application: " + e);
 		}
@@ -696,9 +668,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	public String makeDomainName() {
 		long tm = System.currentTimeMillis();
 
-		return new String(Thread.currentThread()
-						  + String.valueOf(tm + rd.nextInt(12)).substring(10)
-						  + ".com");
+		return new String(Thread.currentThread() + String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
 	}
 
 	/**
@@ -709,27 +679,24 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	public String makeIP() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10));
+		return new String(
+		      String.valueOf(tm + rd.nextInt(50)).substring(10) + "." + String.valueOf(tm + rd.nextInt(50)).substring(10)
+		            + "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
+		            + String.valueOf(tm + rd.nextInt(50)).substring(10));
 	}
 
 	/**
 	 * This method tries to generate a unique Host Name for a given Domain Name
 	 *
-	 * @param newDomainName DOCUMENT ME!
+	 * @param newDomainName
+	 *           DOCUMENT ME!
 	 *
 	 * @return DOCUMENT ME!
 	 */
 	public String makeHostName(String newDomainName) {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-						  + "." + newDomainName);
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + newDomainName);
 	}
 
 	/**
@@ -740,22 +707,20 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	public String makeHostName() {
 		long tm = System.currentTimeMillis();
 
-		return new String("Con"
-						  + String.valueOf(tm + rd.nextInt(5)).substring(7));
+		return new String("Con" + String.valueOf(tm + rd.nextInt(5)).substring(7));
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current     thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 *
-	 * @param aTest name for the test
+	 * @param aTest
+	 *           name for the test
 	 */
 	private void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-							 + iteration + ": ");
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					 + iteration + ": " + aTest + " Start");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
@@ -768,16 +733,15 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	 * Print the end of a test with the <code>Thread</code> name if the current
 	 * thread is a <code>TestThread</code>.
 	 *
-	 * @param aTest name for the test
+	 * @param aTest
+	 *           name for the test
 	 */
 	private void printEnd(String aTest) {
 		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-							 + iteration + ": ");
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					 + iteration + ": " + aTest + " End");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " End");
 		}
 
 		System.out.println("End of " + aTest);
@@ -789,14 +753,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	/**
 	 * Print message
 	 *
-	 * @param aMsg message to print
+	 * @param aMsg
+	 *           message to print
 	 */
 	private void printMsg(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.println(Thread.currentThread().getName()
-							   + ", iteration " + iteration + ": " + aMsg);
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					 + iteration + ": " + aMsg);
+			System.out.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 		else {
 			System.out.println(aMsg);
@@ -809,14 +772,13 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	/**
 	 * Print error message
 	 *
-	 * @param aMsg errpr message to print
+	 * @param aMsg
+	 *           errpr message to print
 	 */
 	private void printError(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.err.println(Thread.currentThread().getName()
-							   + ", iteration " + iteration + ": " + aMsg);
-			cat.error(Thread.currentThread().getName() + ", iteration "
-					  + iteration + ": " + aMsg);
+			System.err.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
+			cat.error(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 		else {
 			System.err.println(aMsg);
@@ -827,5 +789,4 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	// End EPPNamestoreExtHostTst.printError(String)
 }
 
-
 // End class EPPNamestoreExtHostTst
