@@ -353,9 +353,6 @@ public class EPPNameWatchTransferResp extends EPPResponse {
 			aDocument.createElementNS(EPPNameWatchMapFactory.NS, ELM_NAME);
 
 		root.setAttribute("xmlns:nameWatch", EPPNameWatchMapFactory.NS);
-		root.setAttributeNS(
-							EPPCodec.NS_XSI, "xsi:schemaLocation",
-							EPPNameWatchMapFactory.NS_SCHEMA);
 
 		// roid
 		EPPUtil.encodeString(
