@@ -21,7 +21,6 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 package com.verisign.epp.codec.relateddomainext;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.apache.log4j.Logger;
@@ -36,7 +35,7 @@ import com.verisign.epp.codec.gen.EPPUtil;
 import com.verisign.epp.util.EPPCatFactory;
 
 /**
- * EPPCodecComponent that encodes and decodes a <relDom:available> tag
+ * EPPCodecComponent that encodes and decodes a &lt;relDom:available&gt; tag
  * <p>
  * Title: EPP 1.0 Related Domain - available tag
  * </p>
@@ -44,19 +43,10 @@ import com.verisign.epp.util.EPPCatFactory;
  * Description: The EPPRelatedDomainExtAvailable object represents the
  * collection of domains that are available for registration in a family of
  * related domains. As such it is composed of a collection of
- * {@link EPPRelatedDomainExtName} objects. <br/>
- * As XML, it is represented by a <relDom:available> element containing a number
- * of <relDom:name> elements.
+ * {@link EPPRelatedDomainExtName} objects. <br>
+ * As XML, it is represented by a &lt;relDom:available&gt; element containing a number
+ * of &lt;relDom:name&gt; elements.
  * </p>
- * <p>
- * Copyright: Copyright (c) 2013
- * </p>
- * <p>
- * Company: VeriSign
- * </p>
- * 
- * @author nchigurupati
- * @version 1.0
  */
 public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 
@@ -81,7 +71,7 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 
 	/**
 	 * List of domain names represented by the {@link EPPRelatedDomainExtName} to
-	 * be associated with the <relDom:available> element
+	 * be associated with the &lt;relDom:available&gt; element
 	 */
 	private List<EPPRelatedDomainExtName> availableDomains = null;
 
@@ -96,7 +86,7 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 	/**
 	 * Constructor with a list of available domain names.
 	 * 
-	 * @param aAvailableDomains
+	 * @param aAvailableDomains List of available domain names
 	 */
 	public EPPRelatedDomainExtAvailable(
 			final List<EPPRelatedDomainExtName> aAvailableDomains) {
@@ -160,7 +150,7 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 	 * 
 	 * @param aDocument
 	 *        The DOM Document to append data to
-	 * @return Encoded DOM <code>Element</code>
+	 * @return Encoded DOM {@code Element}
 	 * @throws EPPEncodeException
 	 *         Thrown when errors occur during the encode attempt or if the
 	 *         instance is invalid.
@@ -233,8 +223,8 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 	/**
 	 * Are there any available domains included in the list of available domains?
 	 * 
-	 * @return <code>true</code> if the available domain list is not <code>null</code> and
-	 *         there is at least one available domain in the list; <code>false</code>
+	 * @return {@code true} if the available domain list is not {@code null} and
+	 *         there is at least one available domain in the list; {@code false}
 	 *         otherwise.
 	 */
 	public boolean hasAvailableDomains() {
@@ -270,12 +260,12 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 
 
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML {@code String} if successful;
+	 *         {@code ERROR} otherwise.
 	 */
 	@Override
 	public String toString() {
@@ -283,9 +273,9 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the {@code EPPCodecComponent}.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the {@code EPPCodecComponent}. 
 	 */
 	@Override
 	public String getNamespace() {
@@ -294,10 +284,10 @@ public class EPPRelatedDomainExtAvailable implements EPPCodecComponent {
 	
 	
 	/**
-	 * Validate the state of the <code>EPPRelatedDomainExtAvailable</code>
+	 * Validate the state of the {@code EPPRelatedDomainExtAvailable}
 	 * instance. A valid state means that all of the required attributes have been
 	 * set. If validateState returns without an exception, the state is valid. If
-	 * the state is not valid, the <code>EPPCodecException</code> will contain a
+	 * the state is not valid, the {@code EPPCodecException} will contain a
 	 * description of the error. throws EPPCodecException State error. This will
 	 * contain the name of the attribute that is not valid.
 	 * 
