@@ -36,7 +36,7 @@ import com.verisign.epp.codec.gen.EPPUtil;
 import com.verisign.epp.util.EPPCatFactory;
 
 /**
- * EPPCodecComponent that encodes and decodes a <relDom:fields> tag
+ * EPPCodecComponent that encodes and decodes a &lt;relDom:fieldsgt; tag
  * <p>
  * Title: EPP 1.0 Related Domain - fields tag
  * </p>
@@ -44,19 +44,10 @@ import com.verisign.epp.util.EPPCatFactory;
  * Description: The EPPRelatedDomainExtFields object represents the collection
  * of fields that must be synchronized across all the related domains in the
  * family. related domains. As such it is composed of a collection of
- * {@link EPPRelatedDomainExtField} objects. <br/>
- * As XML, it is represented by a <relDom:fields> element containing a number of
- * <relDom:field> elements.
+ * {@link EPPRelatedDomainExtField} objects. <br>
+ * As XML, it is represented by a &lt;relDom:fieldsgt; element containing a number of
+ * &lt;relDom:fieldgt; elements.
  * </p>
- * <p>
- * Copyright: Copyright (c) 2013
- * </p>
- * <p>
- * Company: VeriSign
- * </p>
- * 
- * @author nchigurupati
- * @version 1.0
  */
 public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 
@@ -81,7 +72,7 @@ public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 
 	/**
 	 * List of fields represented by the {@link EPPRelatedDomainExtField} to be
-	 * associated with the <relDom:fields> element
+	 * associated with the &lt;relDom:fieldsgt; element
 	 */
 	private List<EPPRelatedDomainExtField> fields = null;
 
@@ -100,7 +91,7 @@ public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 	}
 
 	/**
-	 * Constructor that takes the required <code>inSync</code> attribute value.
+	 * Constructor that takes the required {@code inSync} attribute value.
 	 * 
 	 * @param aInSync Are the fields in sync?
 	 */
@@ -109,8 +100,8 @@ public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 	}
 	
 	/**
-	 * Constructor that takes both attributes of the <code>EPPRelatedDomainExtFields</code> class including 
-	 * the <code>inSync</code> attribute and the <code>fields</code> attribute.
+	 * Constructor that takes both attributes of the {@code EPPRelatedDomainExtFields} class including 
+	 * the {@code inSync} attribute and the {@code fields} attribute.
 	 * 
 	 * @param aFields List of fields, represented with the {@link EPPRelatedDomainExtField}.  
 	 * @param aInSync Are the fields in sync?
@@ -179,7 +170,7 @@ public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 	 * 
 	 * @param aDocument
 	 *        The DOM Document to append data to
-	 * @return Encoded DOM <code>Element</code>
+	 * @return Encoded DOM {@code Element}
 	 * @throws EPPEncodeException
 	 *         Thrown when errors occur during the encode attempt or if the
 	 *         instance is invalid.
@@ -254,8 +245,8 @@ public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 	/**
 	 * Are there any fields included in the list of fields?
 	 * 
-	 * @return <code>true</code> if the field list is not <code>null</code> and
-	 *         there is at least one field in the list; <code>false</code>
+	 * @return {@code true} if the field list is not {@code null} and
+	 *         there is at least one field in the list; {@code false}
 	 *         otherwise.
 	 */
 	public boolean hasFields() {
@@ -312,24 +303,33 @@ public class EPPRelatedDomainExtFields implements EPPCodecComponent {
 
 
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML {@code String} if successful;
+	 *         {@code ERROR} otherwise.
 	 */
 	@Override
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
+	/**
+	 * Returns the XML namespace associated with the {@code EPPCodecComponent}.
+	 * 
+	 * @return XML namespace for the {@code EPPCodecComponent}. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPRelatedDomainExtFactory.NS;
+	}
 
 	/**
-	 * Validate the state of the <code>EPPRelatedDomainExtFields</code> instance. A
+	 * Validate the state of the {@code EPPRelatedDomainExtFields} instance. A
 	 * valid state means that all of the required attributes have been set. If
 	 * validateState returns without an exception, the state is valid. If the
-	 * state is not valid, the <code>EPPCodecException</code> will contain a
+	 * state is not valid, the {@code EPPCodecException} will contain a
 	 * description of the error. throws EPPCodecException State error. This will
 	 * contain the name of the attribute that is not valid.
 	 * 
