@@ -36,7 +36,7 @@ import com.verisign.epp.codec.gen.EPPUtil;
 import com.verisign.epp.util.EPPCatFactory;
 
 /**
- * EPPCodecComponent that encodes and decodes a <relDom:registered> tag
+ * EPPCodecComponent that encodes and decodes a &lt;relDom:registered&gt; tag
  * <p>
  * Title: EPP 1.0 Related Domain - registered tag
  * </p>
@@ -44,19 +44,10 @@ import com.verisign.epp.util.EPPCatFactory;
  * Description: The EPPRelatedDomainExtRegistered object represents the
  * collection of domains that are registered in a family of related domains. As
  * such it is composed of a collection of {@link EPPRelatedDomainExtName}
- * objects. <br/>
- * As XML, it is represented by a <relDom:registered> element containing a
- * number of <relDom:name> elements.
+ * objects. <br>
+ * As XML, it is represented by a &lt;relDom:registered&gt; element containing a
+ * number of &lt;relDom:name&gt; elements.
  * </p>
- * <p>
- * Copyright: Copyright (c) 2013
- * </p>
- * <p>
- * Company: VeriSign
- * </p>
- * 
- * @author nchigurupati
- * @version 1.0
  */
 public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 
@@ -68,38 +59,33 @@ public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 	/**
 	 * Log4j category for logging
 	 */
-	private static Logger cat = Logger.getLogger(
-			EPPRelatedDomainExtRegistered.class.getName(), EPPCatFactory
-					.getInstance()
-					.getFactory() );
+	private static Logger cat = Logger.getLogger(EPPRelatedDomainExtRegistered.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/**
 	 * Element tag name for registered
 	 */
-	public static final String ELM_NAME = EPPRelatedDomainExtFactory.NS_PREFIX
-			+ ":registered";
+	public static final String ELM_NAME = EPPRelatedDomainExtFactory.NS_PREFIX + ":registered";
 
 	/**
 	 * List of domain names represented by the {@link EPPRelatedDomainExtName} to
-	 * be associated with the <relDom:registered> element
+	 * be associated with the &lt;relDom:registered&gt; element
 	 */
 	private List<EPPRelatedDomainExtName> registeredDomains = null;
 
-
 	/**
 	 * Default constructor
 	 */
-	public EPPRelatedDomainExtRegistered () {
+	public EPPRelatedDomainExtRegistered() {
 	}
 
-
 	/**
 	 * Constructor with a list of registered domain names.
 	 * 
 	 * @param aRegisteredDomains
+	 *           List of registered domain names
 	 */
-	public EPPRelatedDomainExtRegistered(
-			final List<EPPRelatedDomainExtName> aRegisteredDomains) {
+	public EPPRelatedDomainExtRegistered(final List<EPPRelatedDomainExtName> aRegisteredDomains) {
 		this.registeredDomains = aRegisteredDomains;
 
 	}
@@ -118,9 +104,7 @@ public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 			for (EPPRelatedDomainExtName registeredDomain : this.registeredDomains) {
 
 				if (registeredDomain != null) {
-					theClone.registeredDomains
-							.add((EPPRelatedDomainExtName) registeredDomain
-									.clone());
+					theClone.registeredDomains.add((EPPRelatedDomainExtName) registeredDomain.clone());
 				}
 				else {
 					theClone.registeredDomains.add(null);
@@ -141,102 +125,91 @@ public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 	 * Element of the DOM tree
 	 * 
 	 * @param aElement
-	 *        The root element of the report fragment of XML
+	 *           The root element of the report fragment of XML
 	 * @throws EPPDecodeException
-	 *         Thrown if any errors occur during decoding.
+	 *            Thrown if any errors occur during decoding.
 	 */
-	public void decode ( final Element aElement ) throws EPPDecodeException {
+	public void decode(final Element aElement) throws EPPDecodeException {
 
-		this.registeredDomains =
-				EPPUtil.decodeCompList( aElement, EPPRelatedDomainExtFactory.NS,
-						EPPRelatedDomainExtName.ELM_DOMAIN_NAME,
-						EPPRelatedDomainExtName.class );
+		this.registeredDomains = EPPUtil.decodeCompList(aElement, EPPRelatedDomainExtFactory.NS,
+		      EPPRelatedDomainExtName.ELM_DOMAIN_NAME, EPPRelatedDomainExtName.class);
 	}
 
-
 	/**
-	 * Append all data from the list of the list of registered related domain names
-	 * represented by {@link EPPRelatedDomainExtName} to given DOM Document
+	 * Append all data from the list of the list of registered related domain
+	 * names represented by {@link EPPRelatedDomainExtName} to given DOM Document
 	 * 
 	 * @param aDocument
-	 *        The DOM Document to append data to
-	 * @return Encoded DOM <code>Element</code>
+	 *           The DOM Document to append data to
+	 * @return Encoded DOM {@code Element}
 	 * @throws EPPEncodeException
-	 *         Thrown when errors occur during the encode attempt or if the
-	 *         instance is invalid.
+	 *            Thrown when errors occur during the encode attempt or if the
+	 *            instance is invalid.
 	 */
-	public Element encode ( final Document aDocument ) throws EPPEncodeException {
+	public Element encode(final Document aDocument) throws EPPEncodeException {
 
-		if ( aDocument == null ) {
-			throw new EPPEncodeException( "aDocument is null"
-					+ " in EPPRelatedDomainExtRegistered.encode(Document)" );
+		if (aDocument == null) {
+			throw new EPPEncodeException("aDocument is null" + " in EPPRelatedDomainExtRegistered.encode(Document)");
 		}
 
 		try {
 			// Validate States
 			validateState();
 		}
-		catch ( final EPPCodecException e ) {
-			cat
-					.error( "EPPRelatedDomainExtRegistered.encode(): Invalid state on encode: "
-							+ e );
-			throw new EPPEncodeException(
-					"EPPRelatedDomainExtRegistered invalid state: " + e );
+		catch (final EPPCodecException e) {
+			cat.error("EPPRelatedDomainExtRegistered.encode(): Invalid state on encode: " + e);
+			throw new EPPEncodeException("EPPRelatedDomainExtRegistered invalid state: " + e);
 		}
 
-		final Element root =
-				aDocument.createElementNS( EPPRelatedDomainExtFactory.NS, ELM_NAME );
+		final Element root = aDocument.createElementNS(EPPRelatedDomainExtFactory.NS, ELM_NAME);
 
 		// dsData
-		EPPUtil.encodeCompList( aDocument, root, this.registeredDomains );
+		EPPUtil.encodeCompList(aDocument, root, this.registeredDomains);
 		return root;
 	}
 
-
 	/**
 	 * A deep comparison of this with another EPPRelatedDomainExtRegistered.
 	 * 
 	 * @see java.lang.Object#equals(java.lang.Object)
 	 */
-	public boolean equals ( final Object aObj ) {
+	public boolean equals(final Object aObj) {
 
-		if ( !(aObj instanceof EPPRelatedDomainExtRegistered) ) {
+		if (!(aObj instanceof EPPRelatedDomainExtRegistered)) {
 			return false;
 		}
 
-		final EPPRelatedDomainExtRegistered theComp =
-				(EPPRelatedDomainExtRegistered) aObj;
+		final EPPRelatedDomainExtRegistered theComp = (EPPRelatedDomainExtRegistered) aObj;
 
-		if ( !EPPUtil
-				.equalLists( this.registeredDomains, theComp.registeredDomains ) ) {
-			cat
-					.error( "EPPRelatedDomainExtRegistered.equals(): registeredDomains not equal" );
+		if (!EPPUtil.equalLists(this.registeredDomains, theComp.registeredDomains)) {
+			cat.error("EPPRelatedDomainExtRegistered.equals(): registeredDomains not equal");
 			return false;
 		}
 
 		return true;
 	}
 
-	
 	/**
-	 * Adds a registered domain represented by
-	 * {@link EPPRelatedDomainExtName} to the list of registered domains.
+	 * Adds a registered domain represented by {@link EPPRelatedDomainExtName} to
+	 * the list of registered domains.
 	 * 
-	 * @param aRegisteredDomain Registered domain to add to the list.
+	 * @param aRegisteredDomain
+	 *           Registered domain to add to the list.
 	 */
 	public void addRegisteredDomain(EPPRelatedDomainExtName aRegisteredDomain) {
 		if (this.registeredDomains == null) {
 			this.registeredDomains = new ArrayList<EPPRelatedDomainExtName>();
 		}
-		
+
 		this.registeredDomains.add(aRegisteredDomain);
 	}
-	
+
 	/**
-	 * Are there any registered domains included in the list of registered domains?
+	 * Are there any registered domains included in the list of registered
+	 * domains?
 	 * 
-	 * @return <code>true</code> if the registered domain list is not <code>null</code> and
-	 *         there is at least one registered domain in the list; <code>false</code>
+	 * @return {@code true} if the registered domain list is not {@code null} and
+	 *         there is at least one registered domain in the list; {@code false}
 	 *         otherwise.
 	 */
 	public boolean hasRegisteredDomains() {
@@ -253,29 +226,27 @@ public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 	 * 
 	 * @return the registeredDomains
 	 */
-	public List<EPPRelatedDomainExtName> getRegisteredDomains () {
+	public List<EPPRelatedDomainExtName> getRegisteredDomains() {
 		return this.registeredDomains;
 	}
 
-
 	/**
 	 * Sets registeredDomains value to aRegisteredDomains
 	 * 
 	 * @param aRegisteredDomains
-	 *            the registered domains to set
+	 *           the registered domains to set
 	 */
-	public void setRegisteredDomains(
-			final List<EPPRelatedDomainExtName> aRegisteredDomains) {
+	public void setRegisteredDomains(final List<EPPRelatedDomainExtName> aRegisteredDomains) {
 		this.registeredDomains = aRegisteredDomains;
 	}
 
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML {@code String} if successful; {@code ERROR}
+	 *         otherwise.
 	 */
 	@Override
 	public String toString() {
@@ -283,9 +254,9 @@ public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the {@code EPPCodecComponent}.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the {@code EPPCodecComponent}.
 	 */
 	@Override
 	public String getNamespace() {
@@ -293,21 +264,19 @@ public class EPPRelatedDomainExtRegistered implements EPPCodecComponent {
 	}
 
 	/**
-	 * Validate the state of the <code>EPPRelatedDomainExtRegistered</code> instance. A
-	 * valid state means that all of the required attributes have been set. If
+	 * Validate the state of the {@code EPPRelatedDomainExtRegistered} instance.
+	 * A valid state means that all of the required attributes have been set. If
 	 * validateState returns without an exception, the state is valid. If the
-	 * state is not valid, the <code>EPPCodecException</code> will contain a
+	 * state is not valid, the {@code EPPCodecException} will contain a
 	 * description of the error. throws EPPCodecException State error. This will
 	 * contain the name of the attribute that is not valid.
 	 * 
 	 * @throws EPPCodecException
-	 *         Thrown if the instance is in an invalid state
+	 *            Thrown if the instance is in an invalid state
 	 */
-	private void validateState () throws EPPCodecException {
-		if ( (this.registeredDomains == null)
-				|| (this.registeredDomains.size() == 0) ) {
-			throw new EPPCodecException(
-					"EPPRelatedDomainExtRegistered contains no elements." );
+	private void validateState() throws EPPCodecException {
+		if ((this.registeredDomains == null) || (this.registeredDomains.size() == 0)) {
+			throw new EPPCodecException("EPPRelatedDomainExtRegistered contains no elements.");
 		}
 
 	}
