@@ -36,27 +36,19 @@ import com.verisign.epp.codec.gen.EPPUtil;
 import com.verisign.epp.util.EPPCatFactory;
 
 /**
- * EPPCodecComponent that encodes and decodes a <relDom:trnData> tag associated
- * with a Domain-Transfer response.
+ * EPPCodecComponent that encodes and decodes a &lt;relDom:trnData&gt; tag
+ * associated with a Domain-Transfer response.
  * <p>
  * Title: EPP 1.0 Related Domain - trnData tag
  * </p>
  * <p>
  * Description: The EPPRelatedDomainExtTransferResp object represents the
  * collection of domains that have been transferred atomically. As such it is
- * composed of a collection of {@link EPPRelatedDomainExtDomainData} objects. <br/>
- * As XML, it is represented by a <relDom:trnData> element containing a number
- * of <relDom:domain> elements.
+ * composed of a collection of {@link EPPRelatedDomainExtDomainData} objects.
+ * <br>
+ * As XML, it is represented by a &lt;relDom:trnData&gt; element containing a
+ * number of &lt;relDom:domain&gt; elements.
  * </p>
- * <p>
- * Copyright: Copyright (c) 2013
- * </p>
- * <p>
- * Company: VeriSign
- * </p>
- * 
- * @author nchigurupati
- * @version 1.0
  */
 public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 
@@ -68,39 +60,34 @@ public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 	/**
 	 * Log4j category for logging
 	 */
-	private static Logger cat = Logger.getLogger(
-			EPPRelatedDomainExtTransferResp.class.getName(), EPPCatFactory
-					.getInstance()
-					.getFactory() );
+	private static Logger cat = Logger.getLogger(EPPRelatedDomainExtTransferResp.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/**
 	 * Element tag name for trnData
 	 */
-	public static final String ELM_NAME = EPPRelatedDomainExtFactory.NS_PREFIX
-			+ ":trnData";
+	public static final String ELM_NAME = EPPRelatedDomainExtFactory.NS_PREFIX + ":trnData";
 
 	/**
 	 * List of domain names represented by the
 	 * {@link EPPRelatedDomainExtDomainData} to be associated with the
-	 * <relDom:trnData> element
+	 * &lt;relDom:trnData&gt; element
 	 */
 	private List<EPPRelatedDomainExtDomainData> domains = null;
 
-
 	/**
 	 * Default constructor
 	 */
-	public EPPRelatedDomainExtTransferResp () {
+	public EPPRelatedDomainExtTransferResp() {
 	}
 
-
 	/**
 	 * Constructor with a list of domains to be transferred.
 	 * 
 	 * @param aDomains
+	 *           List of domains to be transferred
 	 */
-	public EPPRelatedDomainExtTransferResp(
-			final List<EPPRelatedDomainExtDomainData> aDomains) {
+	public EPPRelatedDomainExtTransferResp(final List<EPPRelatedDomainExtDomainData> aDomains) {
 		this.domains = aDomains;
 	}
 
@@ -110,22 +97,21 @@ public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 	 * @see java.lang.Object#clone()
 	 */
 	@Override
-	public Object clone () throws CloneNotSupportedException {
-		final EPPRelatedDomainExtTransferResp theClone =
-				new EPPRelatedDomainExtTransferResp();
-		
-		if ( this.domains != null ) {
+	public Object clone() throws CloneNotSupportedException {
+		final EPPRelatedDomainExtTransferResp theClone = new EPPRelatedDomainExtTransferResp();
+
+		if (this.domains != null) {
 			theClone.domains = new ArrayList<EPPRelatedDomainExtDomainData>();
-			
+
 			for (EPPRelatedDomainExtDomainData domain : this.domains) {
-				
+
 				if (domain != null) {
 					theClone.domains.add((EPPRelatedDomainExtDomainData) domain.clone());
 				}
 				else {
 					theClone.domains.add(null);
 				}
-				
+
 			}
 		}
 		else {
@@ -135,88 +121,75 @@ public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 		return theClone;
 	}
 
-
 	/**
 	 * Populate the data of this instance with the data stored in the given
 	 * Element of the DOM tree
 	 * 
 	 * @param aElement
-	 *        The root element of the report fragment of XML
+	 *           The root element of the report fragment of XML
 	 * @throws EPPDecodeException
-	 *         Thrown if any errors occur during decoding.
+	 *            Thrown if any errors occur during decoding.
 	 */
-	public void decode ( final Element aElement ) throws EPPDecodeException {
+	public void decode(final Element aElement) throws EPPDecodeException {
 
-		this.domains =
-				EPPUtil.decodeCompList( aElement, EPPRelatedDomainExtFactory.NS,
-						EPPRelatedDomainExtDomainData.ELM_NAME,
-						EPPRelatedDomainExtDomainData.class );
+		this.domains = EPPUtil.decodeCompList(aElement, EPPRelatedDomainExtFactory.NS,
+		      EPPRelatedDomainExtDomainData.ELM_NAME, EPPRelatedDomainExtDomainData.class);
 		try {
 			validateState();
 		}
-		catch ( final EPPCodecException e ) {
-			throw new EPPDecodeException(
-					"Invalid state on EPPRelatedDomainExtDeleteResp.decode: " + e );
+		catch (final EPPCodecException e) {
+			throw new EPPDecodeException("Invalid state on EPPRelatedDomainExtDeleteResp.decode: " + e);
 		}
 	}
 
-
 	/**
 	 * Append all data from the list of the list of domains that have been
 	 * transferred represented by {@link EPPRelatedDomainExtDomainData} to given
 	 * DOM Document
 	 * 
 	 * @param aDocument
-	 *        The DOM Document to append data to
-	 * @return Encoded DOM <code>Element</code>
+	 *           The DOM Document to append data to
+	 * @return Encoded DOM {@code Element}
 	 * @throws EPPEncodeException
-	 *         Thrown when errors occur during the encode attempt or if the
-	 *         instance is invalid.
+	 *            Thrown when errors occur during the encode attempt or if the
+	 *            instance is invalid.
 	 */
-	public Element encode ( final Document aDocument ) throws EPPEncodeException {
+	public Element encode(final Document aDocument) throws EPPEncodeException {
 
-		if ( aDocument == null ) {
-			throw new EPPEncodeException( "aDocument is null"
-					+ " in EPPRelatedDomainExtTransferResp.encode(Document)" );
+		if (aDocument == null) {
+			throw new EPPEncodeException("aDocument is null" + " in EPPRelatedDomainExtTransferResp.encode(Document)");
 		}
 
 		try {
 			// Validate States
 			validateState();
 		}
-		catch ( final EPPCodecException e ) {
-			cat
-					.error( "EPPRelatedDomainExtTransferResp.encode(): Invalid state on encode: "
-							+ e );
-			throw new EPPEncodeException(
-					"EPPRelatedDomainExtTransferResp invalid state: " + e );
+		catch (final EPPCodecException e) {
+			cat.error("EPPRelatedDomainExtTransferResp.encode(): Invalid state on encode: " + e);
+			throw new EPPEncodeException("EPPRelatedDomainExtTransferResp invalid state: " + e);
 		}
 
-		final Element root =
-				aDocument.createElementNS( EPPRelatedDomainExtFactory.NS, ELM_NAME );
-		EPPUtil.encodeCompList( aDocument, root, this.domains );
+		final Element root = aDocument.createElementNS(EPPRelatedDomainExtFactory.NS, ELM_NAME);
+		EPPUtil.encodeCompList(aDocument, root, this.domains);
 		return root;
 	}
 
-
 	/**
 	 * A deep comparison of this with another EPPRelatedDomainExtTransferResp.
 	 * 
 	 * @see java.lang.Object#equals(java.lang.Object)
 	 */
 	@Override
-	public boolean equals ( final Object aObj ) {
+	public boolean equals(final Object aObj) {
 
-		if ( !(aObj instanceof EPPRelatedDomainExtTransferResp) ) {
+		if (!(aObj instanceof EPPRelatedDomainExtTransferResp)) {
 			return false;
 		}
 
-		final EPPRelatedDomainExtTransferResp theComp =
-				(EPPRelatedDomainExtTransferResp) aObj;
+		final EPPRelatedDomainExtTransferResp theComp = (EPPRelatedDomainExtTransferResp) aObj;
 
-		if ( !EPPUtil.equalLists( this.domains, theComp.domains ) ) {
-			cat
-					.error( "EPPRelatedDomainExtTransferResp.equals(): availableDomains not equal" );
+		if (!EPPUtil.equalLists(this.domains, theComp.domains)) {
+			cat.error("EPPRelatedDomainExtTransferResp.equals(): availableDomains not equal");
 			return false;
 		}
 
@@ -224,25 +197,25 @@ public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 	}
 
 	/**
-	 * Adds a related domain represented by
-	 * {@link EPPRelatedDomainExtDomainData} to the list of related domains to transfer.
+	 * Adds a related domain represented by {@link EPPRelatedDomainExtDomainData}
+	 * to the list of related domains to transfer.
 	 * 
-	 * @param aDomain Related domain to add to the list to transfer.
+	 * @param aDomain
+	 *           Related domain to add to the list to transfer.
 	 */
 	public void addDomain(EPPRelatedDomainExtDomainData aDomain) {
 		if (this.domains == null) {
 			this.domains = new ArrayList<EPPRelatedDomainExtDomainData>();
 		}
-		
+
 		this.domains.add(aDomain);
 	}
 
 	/**
 	 * Are there any domains included in the list of domains?
 	 * 
-	 * @return <code>true</code> if the domain list is not <code>null</code> and
-	 *         there is at least one domain in the list; <code>false</code>
-	 *         otherwise.
+	 * @return {@code true} if the domain list is not {@code null} and there is
+	 *         at least one domain in the list; {@code false} otherwise.
 	 */
 	public boolean hasDomains() {
 		if (this.domains != null && this.domains.size() > 0) {
@@ -252,48 +225,45 @@ public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 			return false;
 		}
 	}
-	
-	
+
 	/**
 	 * Returns the list of available related domain names represented by
 	 * {@link EPPRelatedDomainExtDomainData}
 	 * 
 	 * @return the related domains to transfer
 	 */
-	public List<EPPRelatedDomainExtDomainData> getDomains () {
+	public List<EPPRelatedDomainExtDomainData> getDomains() {
 		return this.domains;
 	}
 
-
 	/**
 	 * Sets the list of available related domain names represented by
 	 * {@link EPPRelatedDomainExtDomainData}
 	 * 
 	 * @param aDomains
-	 *        the related domains to set to transfer
+	 *           the related domains to set to transfer
 	 */
-	public void setDomains ( final List<EPPRelatedDomainExtDomainData> aDomains ) {
+	public void setDomains(final List<EPPRelatedDomainExtDomainData> aDomains) {
 		this.domains = aDomains;
 	}
 
-
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 * 		   <code>ERROR</code> otherwise.
+	 * @return Indented XML {@code String} if successful; {@code ERROR}
+	 *         otherwise.
 	 */
 	@Override
-	public String toString () {
+	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the {@code EPPCodecComponent}.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the {@code EPPCodecComponent}.
 	 */
 	@Override
 	public String getNamespace() {
@@ -301,26 +271,25 @@ public class EPPRelatedDomainExtTransferResp implements EPPCodecComponent {
 	}
 
 	/**
-	 * Validate the state of the <code>EPPRelatedDomainExtTransferResp</code>
-	 * instance. A valid state means that all of the required attributes have been
-	 * set. If validateState returns without an exception, the state is valid. If
-	 * the state is not valid, the <code>EPPCodecException</code> will contain a
-	 * description of the error. throws EPPCodecException State error. This will
-	 * contain the name of the attribute that is not valid.
+	 * Validate the state of the {@code EPPRelatedDomainExtTransferResp}
+	 * instance. A valid state means that all of the required attributes have
+	 * been set. If validateState returns without an exception, the state is
+	 * valid. If the state is not valid, the {@code EPPCodecException} will
+	 * contain a description of the error. throws EPPCodecException State error.
+	 * This will contain the name of the attribute that is not valid.
 	 * 
 	 * @throws EPPCodecException
-	 *         Thrown if the instance is in an invalid state
+	 *            Thrown if the instance is in an invalid state
 	 */
-	private void validateState () throws EPPCodecException {
-		if ( (this.domains == null) || (this.domains.size() == 0) ) {
-			throw new EPPCodecException(
-					"EPPRelatedDomainExtTransferResp contains no  elements." );
+	private void validateState() throws EPPCodecException {
+		if ((this.domains == null) || (this.domains.size() == 0)) {
+			throw new EPPCodecException("EPPRelatedDomainExtTransferResp contains no  elements.");
 		}
 
 		for (EPPRelatedDomainExtDomainData domainData : this.domains) {
-			if ( domainData == null ) {
+			if (domainData == null) {
 				throw new EPPCodecException(
-						"EPPRelatedDomainExtTransferResp: contains null EPPRelatedDomainExtDomainData element." );
+				      "EPPRelatedDomainExtTransferResp: contains null EPPRelatedDomainExtDomainData element.");
 			}
 			domainData.validateStateForTransfer();
 		}
