@@ -77,16 +77,14 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * Handle to the Singleton EPP Application instance (
 	 * <code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app = EPPApplicationSingle
-			.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(
-			EPPVerificationCodeDomainTst.class.getName(), EPPCatFactory
-					.getInstance().getFactory());
+	private static final Logger cat = Logger.getLogger(EPPVerificationCodeDomainTst.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
@@ -128,18 +126,18 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	private static final String KEYSTORE_KEY_ALIAS = "verificationcode";
 
 	/**
-	 * Random instance for the generation of unique objects (hosts, IP
-	 * addresses, etc.).
+	 * Random instance for the generation of unique objects (hosts, IP addresses,
+	 * etc.).
 	 */
 	private Random rd = new Random(System.currentTimeMillis());
 
 	/**
 	 * Allocates an <code>EPPVerificationCodeDomainTst</code> with a logical
-	 * name. The constructor will initialize the base class
-	 * <code>TestCase</code> with the logical name.
+	 * name. The constructor will initialize the base class <code>TestCase</code>
+	 * with the logical name.
 	 *
 	 * @param name
-	 *            Logical name of the test
+	 *           Logical name of the test
 	 */
 	public EPPVerificationCodeDomainTst(String name) {
 		super(name);
@@ -181,11 +179,9 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 		EPPEncodedSignedCodeValue encodedSignedCodeValue = null;
 
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 
-			System.out
-					.println("domainCreate: Create domain with single verification code");
+			System.out.println("domainCreate: Create domain with single verification code");
 
 			domain.setTransId("ABC-12345-XYZ");
 
@@ -201,20 +197,16 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 			response = domain.sendCreate();
 
 			// -- Output all of the response attributes
-			System.out.println("domainCreate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("domainCreate: Response = [" + response + "]\n\n");
 
 			// -- Output response attributes using accessors
 			System.out.println("domainCreate: name = " + response.getName());
 
-			System.out.println("domainCreate: expiration date = "
-					+ response.getExpirationDate());
+			System.out.println("domainCreate: expiration date = " + response.getExpirationDate());
 
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 
-			System.out
-					.println("domainCreate: Create domain with multiple verification codes");
+			System.out.println("domainCreate: Create domain with multiple verification codes");
 
 			domain.setTransId("ABC-12345-XYZ");
 
@@ -242,14 +234,12 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 			response = domain.sendCreate();
 
 			// -- Output all of the response attributes
-			System.out.println("domainCreate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("domainCreate: Response = [" + response + "]\n\n");
 
 			// -- Output response attributes using accessors
 			System.out.println("domainCreate: name = " + response.getName());
 
-			System.out.println("domainCreate: expiration date = "
-					+ response.getExpirationDate());
+			System.out.println("domainCreate: expiration date = " + response.getExpirationDate());
 
 		}
 		catch (EPPException e) {
@@ -263,37 +253,31 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * Print out the verification information using the methods.
 	 * 
 	 * @param aTest
-	 *            Test that should prefix the verification information.
+	 *           Test that should prefix the verification information.
 	 * @param aExt
-	 *            The info response extension that contains the verification
-	 *            information.
+	 *           The info response extension that contains the verification
+	 *           information.
 	 */
-	private static void printVerificationInfo(String aTest,
-			EPPVerificationCodeInfData aExt) {
+	private static void printVerificationInfo(String aTest, EPPVerificationCodeInfData aExt) {
 		System.out.println(aTest + ": status = " + aExt.getStatus());
 
 		if (aExt.hasProfiles()) {
 
 			for (EPPVerificationCodeProfile profile : aExt.getProfiles()) {
-				System.out.println(aTest + ": profile = "
-						+ profile.getProfileName());
-				System.out.println(aTest + ": profile status = "
-						+ profile.getStatus());
+				System.out.println(aTest + ": profile = " + profile.getProfileName());
+				System.out.println(aTest + ": profile status = " + profile.getStatus());
 
 				if (profile.hasMissingCodes()) {
 					for (EPPVerificationCode code : profile.getMissingCodes()) {
-						System.out.println(aTest + ": missing code type = "
-								+ code.getType() + ", due date = "
-								+ code.getDueDate());
+						System.out.println(
+						      aTest + ": missing code type = " + code.getType() + ", due date = " + code.getDueDate());
 					}
 				}
 
 				if (profile.hasSetCodes()) {
 					for (EPPVerificationCode code : profile.getSetCodes()) {
-						System.out.println(aTest + ": set code type = "
-								+ code.getType() + ", date = "
-								+ code.getSetDate() + ", value = "
-								+ code.getCode());
+						System.out.println(aTest + ": set code type = " + code.getType() + ", date = " + code.getSetDate()
+						      + ", value = " + code.getCode());
 					}
 				}
 
@@ -314,11 +298,9 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 
 		try {
 			for (int infoCase = 1; infoCase <= 8; infoCase++) {
-				System.out
-						.println("\n----------------------------------------------------------------");
+				System.out.println("\n----------------------------------------------------------------");
 
-				System.out
-						.println("domainInfo: Case " + infoCase + " : Status");
+				System.out.println("domainInfo: Case " + infoCase + " : Status");
 
 				domain.setTransId("ABC-12345-XYZ");
 
@@ -334,15 +316,13 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 				response = domain.sendInfo();
 
 				// -- Output all of the response attributes
-				System.out.println("domainInfo: Response = [" + response
-						+ "]\n\n");
+				System.out.println("domainInfo: Response = [" + response + "]\n\n");
 
 				if (response.hasExtension(EPPVerificationCodeInfData.class)) {
 					EPPVerificationCodeInfData theRespExt = (EPPVerificationCodeInfData) response
-							.getExtension(EPPVerificationCodeInfData.class);
+					      .getExtension(EPPVerificationCodeInfData.class);
 
-					printVerificationInfo("domainInfo - Case " + infoCase,
-							theRespExt);
+					printVerificationInfo("domainInfo - Case " + infoCase, theRespExt);
 				}
 
 			}
@@ -356,17 +336,15 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute
-	 * is initialized with the attributes defined in the EPP sample files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
 
 		// Set attributes for initSession
-		session.setClientID(Environment.getProperty("EPP.Test.clientId",
-				"ClientX"));
-		session.setPassword(Environment.getProperty("EPP.Test.password",
-				"foo-BAR2"));
+		session.setClientID(Environment.getProperty("EPP.Test.clientId", "ClientX"));
+		session.setPassword(Environment.getProperty("EPP.Test.password", "foo-BAR2"));
 		session.setTransId("ABC-12345-XYZ");
 		session.setVersion("1.0");
 		session.setLang("en");
@@ -439,15 +417,13 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-								+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.newInstance();
+					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
 				catch (Exception ex) {
-					Assert.fail("Exception instantiating EPP.SessionClass value "
-							+ theSessionClassName + ": " + ex);
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
@@ -476,8 +452,8 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	}
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPVerificationCodeDomainTst</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>EPPVerificationCodeDomainTst</code>.
 	 *
 	 * @return Test suite
 	 */
@@ -490,8 +466,8 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 
 		// Initialize the PKIX parameters and other DSIG properties
 		try {
-			KeyStore.PrivateKeyEntry keyEntry = loadPrivateKeyEntry(
-					KEYSTORE_FILENAME, KEYSTORE_KEY_ALIAS, KEYSTORE_PASSWORD);
+			KeyStore.PrivateKeyEntry keyEntry = loadPrivateKeyEntry(KEYSTORE_FILENAME, KEYSTORE_KEY_ALIAS,
+			      KEYSTORE_PASSWORD);
 			privateKey = keyEntry.getPrivateKey();
 			certChain = keyEntry.getCertificateChain();
 		}
@@ -520,7 +496,7 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * :&lt;Exception Description&gt;" will be specified.
 	 *
 	 * @param aException
-	 *            Exception thrown during test
+	 *           Exception thrown during test
 	 */
 	public void handleException(Exception aException) {
 		EPPResponse response = session.getResponse();
@@ -541,17 +517,15 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * Unit test main, which accepts the following system property options: <br>
 	 * 
 	 * <ul>
-	 * <li>
-	 * iterations Number of unit test iterations to run</li>
-	 * <li>
-	 * validate Turn XML validation on (<code>true</code>) or off (
+	 * <li>iterations Number of unit test iterations to run</li>
+	 * <li>validate Turn XML validation on (<code>true</code>) or off (
 	 * <code>false</code>). If validate is not specified, validation will be
 	 * off.</li>
 	 * </ul>
 	 * 
 	 *
 	 * @param args
-	 *            Command line arguments
+	 *           Command line arguments
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -573,8 +547,7 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread = new TestThread("EPPSessionTst Thread " + i,
-						EPPVerificationCodeDomainTst.suite());
+				TestThread thread = new TestThread("EPPSessionTst Thread " + i, EPPVerificationCodeDomainTst.suite());
 
 				thread.start();
 			}
@@ -604,8 +577,7 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	public String makeDomainName() {
 		long tm = System.currentTimeMillis();
 
-		return new String(Thread.currentThread()
-				+ String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
+		return new String(Thread.currentThread() + String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
 	}
 
 	/**
@@ -616,25 +588,24 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	public String makeIP() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(50)).substring(10)
-				+ "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
-				+ String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
-				+ String.valueOf(tm + rd.nextInt(50)).substring(10));
+		return new String(
+		      String.valueOf(tm + rd.nextInt(50)).substring(10) + "." + String.valueOf(tm + rd.nextInt(50)).substring(10)
+		            + "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
+		            + String.valueOf(tm + rd.nextInt(50)).substring(10));
 	}
 
 	/**
 	 * Makes a unique host name for a domain using the current time.
 	 *
 	 * @param newDomainName
-	 *            DOCUMENT ME!
+	 *           DOCUMENT ME!
 	 *
 	 * @return Unique host name <code>String</code>
 	 */
 	public String makeHostName(String newDomainName) {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-				+ "." + newDomainName);
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + newDomainName);
 	}
 
 	/**
@@ -645,30 +616,26 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	public String makeContactName() {
 		long tm = System.currentTimeMillis();
 
-		return new String("Con"
-				+ String.valueOf(tm + rd.nextInt(5)).substring(7));
+		return new String("Con" + String.valueOf(tm + rd.nextInt(5)).substring(7));
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 *
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " Start");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
 
-		System.out
-				.println("****************************************************************\n");
+		System.out.println("****************************************************************\n");
 	}
 
 	/**
@@ -676,18 +643,15 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * thread is a <code>TestThread</code>.
 	 *
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printEnd(String aTest) {
-		System.out
-				.println("****************************************************************");
+		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " End");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " End");
 		}
 
 		System.out.println("End of " + aTest);
@@ -699,15 +663,13 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * Print message
 	 *
 	 * @param aMsg
-	 *            message to print
+	 *           message to print
 	 */
 	private void printMsg(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.println(Thread.currentThread().getName()
-					+ ", iteration " + iteration + ": " + aMsg);
+			System.out.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aMsg);
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 
 		else {
@@ -721,15 +683,13 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	 * Print error message
 	 *
 	 * @param aMsg
-	 *            errpr message to print
+	 *           errpr message to print
 	 */
 	private void printError(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.err.println(Thread.currentThread().getName()
-					+ ", iteration " + iteration + ": " + aMsg);
+			System.err.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 
-			cat.error(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aMsg);
+			cat.error(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 
 		else {
@@ -740,26 +700,25 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 	}
 
 	/**
-	 * Loads the private key used to digitally sign from a Java KeyStore with
-	 * the <code>aKeyAliasName</code> alias and the <code>aPassword</code>
-	 * password to access the Keystore and the key.
+	 * Loads the private key used to digitally sign from a Java KeyStore with the
+	 * <code>aKeyAliasName</code> alias and the <code>aPassword</code> password
+	 * to access the Keystore and the key.
 	 * 
 	 * @param aKeyStoreName
-	 *            Java Keystore to load the key from
+	 *           Java Keystore to load the key from
 	 * @param aKeyAliasName
-	 *            Java Keystore alias of key
+	 *           Java Keystore alias of key
 	 * @param aPassword
-	 *            Password to access Java Keystore and key
+	 *           Password to access Java Keystore and key
 	 * 
 	 * @return Loaded <code>KeyStore.PrivateKeyEntry</code> that can be used to
 	 *         get the private key and it's associated certificate chain.
 	 * 
 	 * @throws Exception
-	 *             Error loading private key
+	 *            Error loading private key
 	 */
-	private static KeyStore.PrivateKeyEntry loadPrivateKeyEntry(
-			String aKeyStoreName, String aKeyAliasName, String aPassword)
-			throws Exception {
+	private static KeyStore.PrivateKeyEntry loadPrivateKeyEntry(String aKeyStoreName, String aKeyAliasName,
+	      String aPassword) throws Exception {
 
 		// Load KeyStore
 		KeyStore keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
@@ -768,9 +727,8 @@ public class EPPVerificationCodeDomainTst extends TestCase {
 
 		// Get Private Key
 		assert keyStore.isKeyEntry(aKeyAliasName);
-		KeyStore.PrivateKeyEntry keyEntry = (KeyStore.PrivateKeyEntry) keyStore
-				.getEntry(aKeyAliasName, new KeyStore.PasswordProtection(
-						aPassword.toCharArray()));
+		KeyStore.PrivateKeyEntry keyEntry = (KeyStore.PrivateKeyEntry) keyStore.getEntry(aKeyAliasName,
+		      new KeyStore.PasswordProtection(aPassword.toCharArray()));
 
 		return keyEntry;
 	}
